@@ -1,67 +1,8 @@
 from enum import Enum
-from typing import Optional, Dict, Any, Union, List, TypeVar, Callable, Type, cast
+from typing import Optional, Dict, Any, Union, List
 
-T = TypeVar("T")
-EnumT = TypeVar("EnumT", bound=Enum)
-
-
-def from_dict(f: Callable[[Any], T], x: Any) -> Dict[str, T]:
-    assert isinstance(x, dict)
-    return {k: f(v) for (k, v) in x.items()}
-
-
-def from_none(x: Any) -> Any:
-    assert x is None
-    return x
-
-
-def from_union(fs, x):
-    for f in fs:
-        try:
-            return f(x)
-        except:
-            pass
-    assert False
-
-
-def to_enum(c: Type[EnumT], x: Any) -> EnumT:
-    assert isinstance(x, c)
-    return x.value
-
-
-def from_str(x: Any) -> str:
-    assert isinstance(x, str)
-    return x
-
-
-def from_bool(x: Any) -> bool:
-    assert isinstance(x, bool)
-    return x
-
-
-def to_class(c: Type[T], x: Any) -> dict:
-    assert isinstance(x, c)
-    return cast(Any, x).to_dict()
-
-
-def from_list(f: Callable[[Any], T], x: Any) -> List[T]:
-    assert isinstance(x, list)
-    return [f(y) for y in x]
-
-
-def from_int(x: Any) -> int:
-    assert isinstance(x, int) and not isinstance(x, bool)
-    return x
-
-
-def from_float(x: Any) -> float:
-    assert isinstance(x, (float, int)) and not isinstance(x, bool)
-    return float(x)
-
-
-def to_float(x: Any) -> float:
-    assert isinstance(x, float)
-    return x
+from ..utils import from_str, from_none, from_union, from_list, to_class, to_enum, from_bool, \
+    from_int, from_dict, from_float, to_float
 
 
 class AuthType(Enum):
@@ -1218,8 +1159,8 @@ class PostmanCollection:
         assert isinstance(obj, dict)
         auth = from_union([from_none, Auth.from_dict], obj.get("auth"))
         event = from_union([lambda x: from_list(Event.from_dict, x), from_none], obj.get("event"))
-        info = Information.from_dict(obj.get("info"))
-        item = from_list(Items.from_dict, obj.get("item"))
+        info = from_union([from_none, Information.from_dict], obj.get("info"))
+        item = from_union([lambda x: from_list(Items.from_dict, x), from_none], obj.get("item"))
         protocol_profile_behavior = from_union([lambda x: from_dict(lambda x: x, x), from_none],
                                                obj.get("protocolProfileBehavior"))
         variable = from_union([lambda x: from_list(Variable.from_dict, x), from_none], obj.get("variable"))
